import 'echarts-liquidfill/src/liquidFill.js';
const getTotal = (data) => {
  return data.reduce((num, item) => {
    return num + item.value;
  }, 0);
};

//mergeParams方法
//调用生成对应图表的方法时，extend参数可以对本文件里的基础配置里的字段进行覆盖，
//如果extend里的配置项里的字段为空，说明需要删除本文件里的配置项字段
//例如 options为{ legend :{top:'center',right:'3%'} } , extend参数为 { legend: { top:null,right:null,bottom:'3%',left:'center' } }
//那么合并后的结果对象就是  { legend: {bottom:'3%' ,left:'center' } }
const mergeParams = (options, obj) => {
  let keys = Object.keys(obj);
  keys.forEach((key) => {
    let optionsSubObj = options[key];
    if (optionsSubObj) {
      let subObj = obj[key];
      Object.entries(subObj).forEach((arr) => {
        if (arr[1] === null) {
          delete optionsSubObj[arr[0]];
        } else {
          optionsSubObj[arr[0]] = arr[1];
        }
      });
    }
  });
  return options;
};
const colorList = [
  '#4080FF',
  '#23C343',
  '#37a2da',
  '#32c5e9',
  '#9fe6b8',
  '#ffdb5c',
  '#ff9f7f',
  '#fb7293',
  '#e7bcf3',
  '#8378ea',
  '#47A2FF ',
  '#53C8D1',
  '#59CB74',
  '#FBD444',
  '#7F6AAD',
  '#585247',
  '#ff0000',
];

//堆叠柱状图
export const createStackingBarOption = ({ xData, seriesData }, extend = {}) => {
  return mergeParams(
    {
      tooltip: {
        trigger: 'axis',
        axisPointer: {
          type: 'shadow',
        },
      },
      legend: [
        {
          icon: 'react',
          right: '0%',
          top: '1%',
          textStyle: {
            color: '#595959',
            fontSize: 12,
          },
          itemWidth: 8,
          itemHeight: 8,
          data: seriesData.map((item) => item.name),
        },
      ],
      grid: {
        left: '1%',
        right: '1%',
        bottom: '1%',
        containLabel: true,
      },
      xAxis: {
        type: 'value',
        axisLabel: {
          formatter: '{value}',
          color: '#8c8c8c',
          textStyle: {
            fontSize: 12,
          },
        },
        axisLine: {
          show: false,
        },
        axisTick: {
          show: false,
        },
      },
      yAxis: {
        type: 'category',
        data: xData,
        axisLine: {
          show: false,
        },
        axisTick: {
          show: false,
        },
        axisLabel: {
          margin: 6,
          color: '#8c8c8c',
          textStyle: {
            fontSize: 12,
          },
        },
      },
      series: seriesData.map((item, index) => ({
        name: item.name,
        type: 'bar',
        data: item.data,
        barWidth: '8px',
        stack: '总量',
        // label: {
        //   normal: {
        //     show: true,
        //     position: 'insideRight',
        //   },
        // },
        itemStyle: {
          normal: {
            color: colorList[index % colorList.length],
          },
        },
      })),
    },
    extend
  );
};

//基础柱状图
export const createBarOption = ({ xData, seriesData }, extend = {}) => {
  return mergeParams(
    {
      tooltip: {
        trigger: 'axis',
        axisPointer: {
          type: 'shadow',
        },
      },
      legend: [
        {
          icon: 'react',
          right: '0%',
          top: '1%',
          textStyle: {
            color: '#595959',
            fontSize: 12,
          },
          itemWidth: 8,
          itemHeight: 8,
          data: seriesData.map((item) => item.name),
        },
      ],
      grid: {
        // top: '22%',
        // right: '3%',
        // left: '16%',
        // bottom: '10%',
        left: '1%',
        right: '1%',
        bottom: '1%',
        containLabel: true,
      },
      xAxis: [
        {
          type: 'category',
          data: xData,
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
          axisLabel: {
            margin: 6,
            color: '#8c8c8c',
            textStyle: {
              fontSize: 12,
            },
          },
        },
      ],
      yAxis: [
        {
          axisLabel: {
            formatter: '{value}',
            color: '#8c8c8c',
            textStyle: {
              fontSize: 12,
            },
          },
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
        },
      ],
      series: seriesData.map((item, index) => ({
        name: item.name,
        type: 'bar',
        data: item.data,
        barWidth: '12px',
        itemStyle: {
          normal: {
            color: colorList[index % colorList.length],
          },
        },
      })),
      // series: [
      //   {
      //     name: '当期',
      //     type: 'bar',
      //     data: yDatas[0],
      //     barWidth: '12px',
      //     itemStyle: {
      //       normal: {
      //         color: '#4080FF',
      //       },
      //     },
      //   },
      //   {
      //     name: '同期',
      //     type: 'bar',
      //     data: yDatas[1],
      //     barWidth: '12px',
      //     itemStyle: {
      //       normal: {
      //         color: '#23C343',
      //       },
      //     },
      //   },
      // ],
    },
    extend
  );
};
//创建圆环状的基础饼图
export const createRingPieOption = (
  {
    data,
    title = '',
    center = ['50%', '50%'],
    seriesName = '',
    radius = [40, 60],
  },
  extend = {}
) => {
  const total = getTotal(data);
  return mergeParams(
    {
      tooltip: {
        trigger: 'item',
      },
      legend: {
        orient: 'vertical',
        right: '0%',
        top: 'center',
        icon: 'circle',
        data: data.map((item) => item.name),
        textStyle: {
          color: '#595959',
        },
        itemWidth: 10,
        itemHeight: 10,
        formatter: (name) => {
          let target = data.find((item) => item.name == name);
          let float = ((target.value * 100) / total).toFixed(1);
          return `${name} ${Number(float) + '%'}`;
          //   return `{a|${name}}{b|${Number(float) * 100 + '%'}}`;
        },
      },
      color: colorList,
      series: [
        {
          name: seriesName,
          type: 'pie',
          radius: radius,
          center: center,
          label: {
            position: 'center',
            formatter: () => {
              return `${title}\n{total|${total}}`;
            },
            rich: {
              total: {
                fontSize: 16,
                color: '#262626',
              },
            },
            color: '#8c8c8c',
            fontSize: 12,
            lineHeight: 24,
          },
          labelLine: {
            show: false,
          },
          itemStyle: {
            borderWidth: 2,
            borderColor: '#fff',
          },
          data: data,
        },
      ],
    },
    extend
  );
};
//创建蛋糕试的饼图
export const createCakePieOption = (
  {
    data,
    title = '',
    center = ['35%', '50%'],
    seriesName = '',
    radius = [0, 60],
  },
  extend = {}
) => {
  const total = getTotal(data);
  return mergeParams(
    {
      color: colorList,
      tooltip: {
        trigger: 'item',
        formatter: '{a} <br/>{b} : {c} ({d}%)',
      },
      toolbox: {
        show: true,
      },
      legend: {
        orient: 'vertical',
        right: '1%',
        top: 'center',
        icon: 'circle',
        textStyle: {
          color: '#8C8C8C',
        },
        itemWidth: 10,
        itemHeight: 10,
        // height: 150,
      },
      series: [
        {
          name: seriesName,
          type: 'pie',
          radius: radius,
          center: center,
          data: data,
          label: {
            show: false,
          },
        },
      ],
    },
    extend
  );
};
//基础水球图
export const createWaterBallOption = (
  { data, title, center, radius = '90%', color = '64,128,255' },
  extend = {}
) => {
  return mergeParams(
    {
      // backgroundColor: "#0e2147",
      // title: {
      //   show: true,
      //   text: title,
      //   x: 'center',
      //   y: '50%',
      //   z: 10,
      //   textStyle: {
      //     color: '#666',
      //     fontSize: 12,
      //     // fontWeight: 500,
      //   },
      // },
      // title: {
      //   //   text: (value * 100).toFixed(0) + '{a|%}',
      //   text: 30 + '{a|%}',
      //   textStyle: {
      //     fontSize: 50,
      //     fontFamily: 'Microsoft Yahei',
      //     fontWeight: 'normal',
      //     color: '#bcb8fb',
      //     rich: {
      //       a: {
      //         fontSize: 28,
      //       },
      //     },
      //   },
      //   x: 'center',
      //   y: '35%',
      // },
      graphic: [
        {
          type: 'group',
          left: 'center',
          top: '34%',
          children: [
            {
              type: 'text',
              z: 100,
              left: '10',
              top: 'middle',
              style: {
                fill: '#fff',
                text: title,
                font: '12px Microsoft YaHei',
              },
            },
          ],
        },
      ],
      series: [
        {
          name: 'test',
          type: 'liquidFill',
          radius: radius,
          center: center || ['50%', '50%'],
          data: [data],
          label: {
            normal: {
              // formatter: '',
              position: ['50%', '66%'],
              textStyle: {
                color: '#333',
                fontSize: 20,
              },
            },
          },
          color: [`rgba(${color},1)`],
          backgroundStyle: {
            color: `rgba(${color},0.26)`,
          },
          outline: {
            borderDistance: 0,
            itemStyle: {
              borderWidth: 10,
              borderColor: `rgba(${color},0.5)`,
            },
          },
          // amplitude: 0,
        },
      ],
    },
    extend
  );
};
